@@ -43,9 +43,14 @@ from .functions import Gauss2d
 from .functions import Gauss3d
 from .functions import TwoGauss2d
 from .functions import Lorentz1d
+from .functions import Lorentz1d_der_x
+from .functions import Lorentz1d_der_p
 from .functions import Lorentz2d
+from .functions import PseudoVoigt1d
 
 from .fit import fit_peak2d
 from .fit import gauss_fit
+from .fit import multPeakFit
+from .fit import multPeakPlot 
 from .fit import multGaussFit
 from .fit import multGaussPlot 
